@@ -7,7 +7,7 @@
 #include <QFile>
 
 //select calendars that have recursive events
-const QString SQL_GET_CAL_WITH_RECURRING =  "select distinct a.calendarid, a.name, a.colour from calendars a join components b on a.calendarid=b.calendarid join recursive c on b.id=c.id";
+const QString SQL_GET_CAL_WITH_RECURRING =  "select distinct a.calendarid, a.name, a.colour, ' ' delegate, calendartype from calendars a join components b on a.calendarid=b.calendarid join recursive c on b.id=c.id where a.isreadonly = 0";
 
 //select recursive events for a specific calendar
 #define SQL_GET_
